All Classes and Interfaces
Class
Description
Abstract WebFlux Test
Abstract class for WebMVC testing
AnnotatedTypeMetadata Test FactoryEmbedded database types
The annotation to startup the Embedded Tomcat server for Spring integration testing.
The Tomcat features
The annotation to startup the Embedded Zookeeper server for Spring integration testing.
Enable an embedded database
Mock
ServletWebRequestPerson Handler
Person Handler
RouterFunction Test ConfigRouterFunction Test ConfigThe utility class for Servlet Testing
SimpleUrlHandlerMapping Test ConfigSimpleUrlHandlerMapping Test ConfigThe annotation for Spring logging test with levels : TRACE , INFO , ERROR
Spring Test Utilities class
Web Utilities class for Spring Test
ConditionContext for testingTest
@RestControllerFilter for testingTest
FilterRegistration.DynamicServlet for TestingTest
ServletContext based on MockServletContextServletContextListener for testingTest
ServletRegistration.DynamicUser POJO
The utility class for testing in Spring Web