Index
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form
A
- AbstractWebFluxTest - Class in io.microsphere.spring.test.webflux
-
Abstract WebFlux Test
- AbstractWebFluxTest() - Constructor for class io.microsphere.spring.test.webflux.AbstractWebFluxTest
- AbstractWebMvcTest - Class in io.microsphere.spring.test.webmvc
-
Abstract class for WebMVC testing
- AbstractWebMvcTest() - Constructor for class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
- addFilter(String, Filter) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addFilter(String, Class<? extends Filter>) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addFilter(String, String) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addFilter(String, String, Filter) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addListener(Class<? extends EventListener>) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addListener(String) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addListener(T) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addMapping(String...) - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- addMappingForServletNames(EnumSet<DispatcherType>, boolean, String...) - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- addMappingForUrlPatterns(EnumSet<DispatcherType>, boolean, String...) - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- addServlet(String, Servlet) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addServlet(String, Class<? extends Servlet>) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addServlet(String, String) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addServlet(String, String, Servlet) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- addTestFilter(ServletContext) - Static method in class io.microsphere.spring.test.util.ServletTestUtils
-
Adds a test filter to the provided
ServletContext. - addTestServlet(ServletContext) - Static method in class io.microsphere.spring.test.util.ServletTestUtils
-
Adds a test servlet to the provided
ServletContext. - alternativeWebXml() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
The resource location of an alternative deployment descriptor for the web application.
- AnnotatedTypeMetadataTestFactory - Class in io.microsphere.spring.test.context.annotation
-
AnnotatedTypeMetadataTest Factory - AnnotatedTypeMetadataTestFactory() - Constructor for class io.microsphere.spring.test.context.annotation.AnnotatedTypeMetadataTestFactory
- ATTRIBUTE_NAME - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- ATTRIBUTE_VALUE - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- AUTH_NAME - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- AUTH_VALUE - Static variable in class io.microsphere.spring.test.web.WebTestUtils
B
- BASE_PATH - Static variable in class io.microsphere.spring.test.webflux.SimpleUrlHandlerMappingTestConfig
- BASE_PATH - Static variable in class io.microsphere.spring.test.webmvc.SimpleUrlHandlerMappingTestConfig
- basedir() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
The resource location of the Tomcat's
base directory. - buildWebTestClient(ConfigurableApplicationContext) - Method in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
C
- classes() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
The component classes to use for loading an
ApplicationContext. - clearAttributes(NativeWebRequest) - Static method in class io.microsphere.spring.test.util.SpringTestWebUtils
-
Clears all attributes from the request scope of the given
NativeWebRequest. - clearAttributes(NativeWebRequest, int) - Static method in class io.microsphere.spring.test.util.SpringTestWebUtils
-
Clears all attributes from the specified scope of the given
NativeWebRequest. - context - Variable in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
- context - Variable in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
- contextDestroyed(ServletContextEvent) - Method in class io.microsphere.spring.test.web.servlet.TestServletContextListener
- contextInitialized(ServletContextEvent) - Method in class io.microsphere.spring.test.web.servlet.TestServletContextListener
- contextPath() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
The context path of Tomcat
- createFilter(Class<T>) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- createInstance(Class<T>) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- createInstance(String) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- createListener(Class<T>) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- createMethodAnnotatedTypeMetadata() - Method in class io.microsphere.spring.test.context.annotation.AnnotatedTypeMetadataTestFactory
- createPerson(ServerRequest) - Method in class io.microsphere.spring.test.webflux.PersonHandler
- createPerson(ServerRequest) - Method in class io.microsphere.spring.test.webmvc.PersonHandler
- createPreFightRequest() - Static method in class io.microsphere.spring.test.util.SpringTestWebUtils
-
Creates a new instance of
NativeWebRequestfor CORS pre-flight requests. - createServlet(Class<T>) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- createWebRequest() - Static method in class io.microsphere.spring.test.util.SpringTestWebUtils
-
Creates a new instance of
NativeWebRequestwith default settings. - createWebRequest(String) - Static method in class io.microsphere.spring.test.util.SpringTestWebUtils
-
Creates a new instance of
NativeWebRequestwith the specified request URI. - createWebRequest(Consumer<MockHttpServletRequest>) - Static method in class io.microsphere.spring.test.util.SpringTestWebUtils
-
Creates a new instance of
NativeWebRequestwith custom settings provided by the givenConsumer. - createWebRequestWithHeaders(Object...) - Static method in class io.microsphere.spring.test.util.SpringTestWebUtils
-
Creates a new instance of
NativeWebRequestwith the specified request headers. - createWebRequestWithHeaders(Map<String, String>) - Static method in class io.microsphere.spring.test.util.SpringTestWebUtils
-
Creates a new instance of
NativeWebRequestwith the specified request headers. - createWebRequestWithParams(Object...) - Static method in class io.microsphere.spring.test.util.SpringTestWebUtils
-
Creates a new instance of
NativeWebRequestwith the specified request parameters.
D
- dataDir() - Element in annotation interface io.microsphere.spring.test.zookeeper.embedded.EmbeddedZookeeperServer
-
The resource location of the Zookeeper Server
- dataSource() - Element in annotation interface io.microsphere.spring.test.jdbc.embedded.EnableEmbeddedDatabase
- DEFAULT_FILTER_NAME - Static variable in class io.microsphere.spring.test.web.servlet.TestFilter
-
Default Filter Name
- DEFAULT_FILTER_URL_PATTERN - Static variable in class io.microsphere.spring.test.web.servlet.TestFilter
-
Default URL Pattern
- DEFAULT_SERVLET_NAME - Static variable in class io.microsphere.spring.test.web.servlet.TestServlet
-
Default Servlet Name : "testServlet"
- DEFAULT_SERVLET_URL_PATTERN - Static variable in class io.microsphere.spring.test.web.servlet.TestServlet
-
Default URL Pattern : "/testServlet"
- DEFAULT_WEB_XML - Enum constant in enum class io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration.Feature
-
Add the default web.xml file to the context
- deletePerson(ServerRequest) - Method in class io.microsphere.spring.test.webflux.PersonHandler
- deletePerson(ServerRequest) - Method in class io.microsphere.spring.test.webmvc.PersonHandler
- destroy() - Method in class io.microsphere.spring.test.web.servlet.TestFilter
- docBase() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
The resource location of the Tomcat's
the root directory of context document. - doDelete(HttpServletRequest, HttpServletResponse) - Method in class io.microsphere.spring.test.web.servlet.TestServlet
- doFilter(ServletRequest, ServletResponse, FilterChain) - Method in class io.microsphere.spring.test.web.servlet.TestFilter
- doGet(HttpServletRequest, HttpServletResponse) - Method in class io.microsphere.spring.test.web.servlet.TestServlet
- doHead(HttpServletRequest, HttpServletResponse) - Method in class io.microsphere.spring.test.web.servlet.TestServlet
- doPost(HttpServletRequest, HttpServletResponse) - Method in class io.microsphere.spring.test.web.servlet.TestServlet
- doPut(HttpServletRequest, HttpServletResponse) - Method in class io.microsphere.spring.test.web.servlet.TestServlet
- doService(HttpServletRequest, HttpServletResponse) - Method in class io.microsphere.spring.test.web.servlet.TestServlet
E
- EmbeddedDatabaseType - Enum Class in io.microsphere.spring.test.jdbc.embedded
-
Embedded database types
- EmbeddedTomcatConfiguration - Annotation Interface in io.microsphere.spring.test.tomcat.embedded
-
The annotation to startup the Embedded Tomcat server for Spring integration testing.
- EmbeddedTomcatConfiguration.Feature - Enum Class in io.microsphere.spring.test.tomcat.embedded
-
The Tomcat features
- EmbeddedZookeeperServer - Annotation Interface in io.microsphere.spring.test.zookeeper.embedded
-
The annotation to startup the Embedded Zookeeper server for Spring integration testing.
- EnableEmbeddedDatabase - Annotation Interface in io.microsphere.spring.test.jdbc.embedded
-
Enable an embedded database
- EnableEmbeddedDatabases - Annotation Interface in io.microsphere.spring.test.jdbc.embedded
- equals(Object) - Method in class io.microsphere.spring.test.domain.User
- error(String) - Method in class io.microsphere.spring.test.web.controller.TestController
F
- features() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
Enable the Tomcat features
- FILTER_CLASS_NAME - Static variable in class io.microsphere.spring.test.web.servlet.TestFilter
-
Filter Class Name
- FIRST_PATH - Static variable in class io.microsphere.spring.test.webflux.SimpleUrlHandlerMappingTestConfig
- FIRST_PATH - Static variable in class io.microsphere.spring.test.webmvc.SimpleUrlHandlerMappingTestConfig
G
- GET_PERSON_PATH - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- getAge() - Method in class io.microsphere.spring.test.domain.User
- getBeanFactory() - Method in class io.microsphere.spring.test.context.annotation.TestConditionContext
- getClassLoader() - Method in class io.microsphere.spring.test.context.annotation.TestConditionContext
- getClassName() - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- getClassName() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- getEnvironment() - Method in class io.microsphere.spring.test.context.annotation.TestConditionContext
- getFilter() - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
-
Get the Filter
- getFilterRegistration(String) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- getFilterRegistrations() - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- getInitParameter(String) - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- getInitParameter(String) - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- getInitParameters() - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- getInitParameters() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- getLoadOnStartup() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
-
Get Load On Startup
- getMappings() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- getMockHttpServletRequest() - Method in class io.microsphere.spring.test.web.context.request.MockServletWebRequest
- getMockHttpServletResponse() - Method in class io.microsphere.spring.test.web.context.request.MockServletWebRequest
- getMultipartConfig() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
-
Get Multipart Config
- getName() - Method in class io.microsphere.spring.test.domain.User
- getName() - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- getName() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- getPerson(ServerRequest) - Method in class io.microsphere.spring.test.webflux.PersonHandler
- getPerson(ServerRequest) - Method in class io.microsphere.spring.test.webmvc.PersonHandler
- getRegistry() - Method in class io.microsphere.spring.test.context.annotation.TestConditionContext
- getResourceLoader() - Method in class io.microsphere.spring.test.context.annotation.TestConditionContext
- getRoleName() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
-
Get Role Name
- getRunAsRole() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- getServlet() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- getServletNameMappings() - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- getServletRegistration(String) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- getServletRegistrations() - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- getServletSecurityElement() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
-
Get Servlet Security Element
- getUrlPatternMappings() - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- getUrlPatterns() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
-
Get URL Patterns
- getValue(Mono<T>) - Static method in class io.microsphere.spring.test.web.WebTestUtils
-
Get the emitted value from
Mono - greeting(String) - Method in class io.microsphere.spring.test.web.controller.TestController
H
- hashCode() - Method in class io.microsphere.spring.test.domain.User
- HEADER_NAME - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- HEADER_NAME_2 - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- HEADER_VALUE - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- HEADER_VALUE_2 - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- helloWorld() - Method in class io.microsphere.spring.test.web.controller.TestController
I
- inheritInitializers() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
Whether context initializers from test superclasses and enclosing classes should be inherited.
- inheritLocations() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
Whether resource locations or component classes from test superclasses and enclosing classes should be inherited.
- init(FilterConfig) - Method in class io.microsphere.spring.test.web.servlet.TestFilter
- initializers() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
The application context initializer classes to use for initializing a
ConfigurableApplicationContext. - io.microsphere.spring.test.context.annotation - package io.microsphere.spring.test.context.annotation
- io.microsphere.spring.test.domain - package io.microsphere.spring.test.domain
- io.microsphere.spring.test.jdbc.embedded - package io.microsphere.spring.test.jdbc.embedded
- io.microsphere.spring.test.junit.jupiter - package io.microsphere.spring.test.junit.jupiter
- io.microsphere.spring.test.tomcat.embedded - package io.microsphere.spring.test.tomcat.embedded
- io.microsphere.spring.test.util - package io.microsphere.spring.test.util
- io.microsphere.spring.test.web - package io.microsphere.spring.test.web
- io.microsphere.spring.test.web.context.request - package io.microsphere.spring.test.web.context.request
- io.microsphere.spring.test.web.controller - package io.microsphere.spring.test.web.controller
- io.microsphere.spring.test.web.servlet - package io.microsphere.spring.test.web.servlet
- io.microsphere.spring.test.webflux - package io.microsphere.spring.test.webflux
- io.microsphere.spring.test.webmvc - package io.microsphere.spring.test.webmvc
- io.microsphere.spring.test.zookeeper.embedded - package io.microsphere.spring.test.zookeeper.embedded
- isAsyncSupported() - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
-
Get the Async Supported
- isAsyncSupported() - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
-
Get Async Supported
L
- listPeople(ServerRequest) - Method in class io.microsphere.spring.test.webflux.PersonHandler
- listPeople(ServerRequest) - Method in class io.microsphere.spring.test.webmvc.PersonHandler
- loadClass(String) - Method in class io.microsphere.spring.test.web.servlet.TestServletContext
- locations() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
The resource locations to use for loading an
ApplicationContext. - logger - Variable in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
M
- mockMvc - Variable in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
- mockServerWebExchange() - Static method in class io.microsphere.spring.test.web.WebTestUtils
- MockServletWebRequest - Class in io.microsphere.spring.test.web.context.request
-
Mock
ServletWebRequest - MockServletWebRequest() - Constructor for class io.microsphere.spring.test.web.context.request.MockServletWebRequest
- MockServletWebRequest(ServletContext) - Constructor for class io.microsphere.spring.test.web.context.request.MockServletWebRequest
N
- NAMING - Enum constant in enum class io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration.Feature
-
Enables the JNDI feature
- nestedPersonRouterFunction(PersonHandler) - Method in class io.microsphere.spring.test.webflux.RouterFunctionTestConfig
- nestedPersonRouterFunction(PersonHandler) - Method in class io.microsphere.spring.test.webmvc.RouterFunctionTestConfig
- NOT_FOUND_ATTRIBUTE_NAME - Static variable in class io.microsphere.spring.test.web.WebTestUtils
P
- PARAM_NAME - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- PARAM_NAME_2 - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- PARAM_VALUE - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- PARAM_VALUE_2 - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- PATH_ATTRIBUTE - Static variable in class io.microsphere.spring.test.util.SpringTestWebUtils
- PERSON_ID_PATH - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- PERSON_PATH - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- PERSON_TEST_PATH - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- PersonHandler - Class in io.microsphere.spring.test.webflux
-
Person Handler
- PersonHandler - Class in io.microsphere.spring.test.webmvc
-
Person Handler
- PersonHandler() - Constructor for class io.microsphere.spring.test.webflux.PersonHandler
- PersonHandler() - Constructor for class io.microsphere.spring.test.webmvc.PersonHandler
- personRouterFunction(PersonHandler) - Method in class io.microsphere.spring.test.webflux.RouterFunctionTestConfig
- personRouterFunction(PersonHandler) - Method in class io.microsphere.spring.test.webmvc.RouterFunctionTestConfig
- port() - Element in annotation interface io.microsphere.spring.test.jdbc.embedded.EnableEmbeddedDatabase
-
JDBC connection port
- port() - Element in annotation interface io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration
-
The port of Tomcat
- port() - Element in annotation interface io.microsphere.spring.test.zookeeper.embedded.EmbeddedZookeeperServer
-
The port of Zookeeper Server
- primary() - Element in annotation interface io.microsphere.spring.test.jdbc.embedded.EnableEmbeddedDatabase
- properties() - Element in annotation interface io.microsphere.spring.test.jdbc.embedded.EnableEmbeddedDatabase
R
- REMOTE_ADDRESS - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- responseEntity() - Method in class io.microsphere.spring.test.web.controller.TestController
- RouterFunctionTestConfig - Class in io.microsphere.spring.test.webflux
-
RouterFunctionTest Config - RouterFunctionTestConfig - Class in io.microsphere.spring.test.webmvc
-
RouterFunctionTest Config - RouterFunctionTestConfig() - Constructor for class io.microsphere.spring.test.webflux.RouterFunctionTestConfig
- RouterFunctionTestConfig() - Constructor for class io.microsphere.spring.test.webmvc.RouterFunctionTestConfig
S
- SERVLET_CLASS - Static variable in class io.microsphere.spring.test.web.servlet.TestServlet
-
Servlet Class
- SERVLET_CLASS_NAME - Static variable in class io.microsphere.spring.test.web.servlet.TestServlet
-
Servlet Class Name
- ServletTestUtils - Class in io.microsphere.spring.test.util
-
The utility class for Servlet Testing
- setAge(int) - Method in class io.microsphere.spring.test.domain.User
- setApplicationContext(ApplicationContext) - Method in class io.microsphere.spring.test.context.annotation.TestConditionContext
- setAsyncSupported(boolean) - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- setAsyncSupported(boolean) - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- setBeanClassLoader(ClassLoader) - Method in class io.microsphere.spring.test.context.annotation.AnnotatedTypeMetadataTestFactory
- setInitParameter(String, String) - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- setInitParameter(String, String) - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- setInitParameters(Map<String, String>) - Method in class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- setInitParameters(Map<String, String>) - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- setLoadOnStartup(int) - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- setMultipartConfig(MultipartConfigElement) - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- setName(String) - Method in class io.microsphere.spring.test.domain.User
- setRunAsRole(String) - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- setServletSecurity(ServletSecurityElement) - Method in class io.microsphere.spring.test.web.servlet.TestServletRegistration
- setUp() - Method in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
- SILENT - Enum constant in enum class io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration.Feature
-
Controls the loggers will be silenced.
- simpleUrlHandlerMapping() - Method in class io.microsphere.spring.test.webflux.SimpleUrlHandlerMappingTestConfig
- simpleUrlHandlerMapping() - Method in class io.microsphere.spring.test.webmvc.SimpleUrlHandlerMappingTestConfig
- SimpleUrlHandlerMappingTestConfig - Class in io.microsphere.spring.test.webflux
-
SimpleUrlHandlerMappingTest Config - SimpleUrlHandlerMappingTestConfig - Class in io.microsphere.spring.test.webmvc
-
SimpleUrlHandlerMappingTest Config - SimpleUrlHandlerMappingTestConfig() - Constructor for class io.microsphere.spring.test.webflux.SimpleUrlHandlerMappingTestConfig
- SimpleUrlHandlerMappingTestConfig() - Constructor for class io.microsphere.spring.test.webmvc.SimpleUrlHandlerMappingTestConfig
- SpringLoggingTest - Annotation Interface in io.microsphere.spring.test.junit.jupiter
-
The annotation for Spring logging test with levels : TRACE , INFO , ERROR
- SpringTestUtils - Class in io.microsphere.spring.test.util
-
Spring Test Utilities class
- SpringTestWebUtils - Class in io.microsphere.spring.test.util
-
Web Utilities class for Spring Test
- SQLITE - Enum constant in enum class io.microsphere.spring.test.jdbc.embedded.EmbeddedDatabaseType
T
- TEST_ROOT_PATH - Static variable in class io.microsphere.spring.test.web.WebTestUtils
- TestConditionContext - Class in io.microsphere.spring.test.context.annotation
-
ConditionContextfor testing - TestConditionContext() - Constructor for class io.microsphere.spring.test.context.annotation.TestConditionContext
- testController - Variable in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
- TestController - Class in io.microsphere.spring.test.web.controller
-
Test
@RestController - TestController() - Constructor for class io.microsphere.spring.test.web.controller.TestController
- testError() - Method in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
- testError() - Method in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
- TestFilter - Class in io.microsphere.spring.test.web.servlet
-
Filterfor testing - TestFilter() - Constructor for class io.microsphere.spring.test.web.servlet.TestFilter
- TestFilterRegistration - Class in io.microsphere.spring.test.web.servlet
-
Test
FilterRegistration.Dynamic - TestFilterRegistration(String, String, Filter) - Constructor for class io.microsphere.spring.test.web.servlet.TestFilterRegistration
- testGreeting() - Method in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
- testGreeting() - Method in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
- testHelloWorld() - Method in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
- testHelloWorld() - Method in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
- testInSpringContainer(ThrowableBiConsumer<ConfigurableApplicationContext, ConfigurableEnvironment>, Class<?>...) - Static method in class io.microsphere.spring.test.util.SpringTestUtils
-
Executes the given
ThrowableBiConsumerwithin a Spring container context. - testInSpringContainer(ThrowableConsumer<ConfigurableApplicationContext>, Class<?>...) - Static method in class io.microsphere.spring.test.util.SpringTestUtils
-
Executes the given
ThrowableConsumerwithin a Spring container context. - testResponseEntity() - Method in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
- testResponseEntity() - Method in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
- TestServlet - Class in io.microsphere.spring.test.web.servlet
-
Servletfor Testing - TestServlet() - Constructor for class io.microsphere.spring.test.web.servlet.TestServlet
- TestServletContext - Class in io.microsphere.spring.test.web.servlet
-
Test
ServletContextbased onMockServletContext - TestServletContext() - Constructor for class io.microsphere.spring.test.web.servlet.TestServletContext
-
Create a new
TestServletContext, using no base path and aDefaultResourceLoader(i.e. the classpath root as WAR root). - TestServletContext(String) - Constructor for class io.microsphere.spring.test.web.servlet.TestServletContext
-
Create a new
TestServletContext, using aDefaultResourceLoader. - TestServletContext(String, ResourceLoader) - Constructor for class io.microsphere.spring.test.web.servlet.TestServletContext
-
Create a new
TestServletContextusing the supplied resource base path and resource loader. - TestServletContextListener - Class in io.microsphere.spring.test.web.servlet
-
ServletContextListenerfor testing - TestServletContextListener() - Constructor for class io.microsphere.spring.test.web.servlet.TestServletContextListener
- TestServletRegistration - Class in io.microsphere.spring.test.web.servlet
-
Test
ServletRegistration.Dynamic - TestServletRegistration(String, String, Servlet) - Constructor for class io.microsphere.spring.test.web.servlet.TestServletRegistration
- testUpdatePerson() - Method in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
- testUpdatePerson() - Method in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
-
Test RouterFunctionTestConfig#nestedPersonRouterFunction(PersonHandler)
- testUser() - Method in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
- testUser() - Method in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
- testView() - Method in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
- testWebEndpoints() - Method in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
-
Test the Web Endpoints
- testWebEndpoints() - Method in class io.microsphere.spring.test.webmvc.AbstractWebMvcTest
-
Test the Web Endpoints
- tickTime() - Element in annotation interface io.microsphere.spring.test.zookeeper.embedded.EmbeddedZookeeperServer
-
The tick time of Zookeeper Server
- toString() - Method in class io.microsphere.spring.test.domain.User
- type() - Element in annotation interface io.microsphere.spring.test.jdbc.embedded.EnableEmbeddedDatabase
U
- updatePerson(ServerRequest) - Method in class io.microsphere.spring.test.webflux.PersonHandler
- updatePerson(ServerRequest) - Method in class io.microsphere.spring.test.webmvc.PersonHandler
- USE_TEST_CLASSPATH - Enum constant in enum class io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration.Feature
-
Uses test dependencies rather than only runtime
- user(User) - Method in class io.microsphere.spring.test.web.controller.TestController
- User - Class in io.microsphere.spring.test.domain
-
User POJO
- User() - Constructor for class io.microsphere.spring.test.domain.User
- User(String, int) - Constructor for class io.microsphere.spring.test.domain.User
V
- value() - Element in annotation interface io.microsphere.spring.test.jdbc.embedded.EnableEmbeddedDatabases
- valueOf(String) - Static method in enum class io.microsphere.spring.test.jdbc.embedded.EmbeddedDatabaseType
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration.Feature
-
Returns the enum constant of this class with the specified name.
- values() - Static method in enum class io.microsphere.spring.test.jdbc.embedded.EmbeddedDatabaseType
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration.Feature
-
Returns an array containing the constants of this enum class, in the order they are declared.
- view() - Method in class io.microsphere.spring.test.web.controller.TestController
W
- WEB_APP_DEFAULTS - Enum constant in enum class io.microsphere.spring.test.tomcat.embedded.EmbeddedTomcatConfiguration.Feature
-
Provide default configuration for a context.
- webTestClient - Variable in class io.microsphere.spring.test.webflux.AbstractWebFluxTest
- WebTestUtils - Class in io.microsphere.spring.test.web
-
The utility class for testing in Spring Web
- WebTestUtils() - Constructor for class io.microsphere.spring.test.web.WebTestUtils
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form